from setuptools import setup

setup(name = 'funniesty',
	  version = '0.2',
	  description = 'The funniest joke in the world. NOT SO MUCH',
	  url = 'http://www.stangggtestsite/wp',
	  author = 'Flying Circus',
	  author_email = 'flyingcircus@example.com',
	  license = 'MIT',
	  packages = ['funniesty'],
	  install_requires = ['markdown'],
	  zip_safe = False)